@@ -118,6 +118,10 @@
             href: 'library.html',
             name: Globalize.translate('TabFolders')
         },
+         {
+             href: 'librarydisplay.html',
+             name: Globalize.translate('TabDisplay')
+         },
          {
              href: 'librarypathmapping.html',
              name: Globalize.translate('TabPathSubstitution')
@@ -139,7 +143,7 @@
 
     }).on('pageshow', "#libraryPathMappingPage", function () {
 
-        LibraryMenu.setTabs('librarysetup', 1, getTabs);
+        LibraryMenu.setTabs('librarysetup', 2, getTabs);
         Dashboard.showLoadingMsg();
 
         var page = this;
