@@ -1,4 +1,4 @@
-﻿define(['jQuery', 'libraryBrowser', 'scrollStyles'], function ($, libraryBrowser) {
+﻿define(['libraryBrowser', 'scrollStyles'], function (libraryBrowser) {
 
     function getView() {
 
@@ -75,7 +75,7 @@
 
     function loadResume(page, userId, parentId) {
 
-        var screenWidth = $(window).width();
+        var screenWidth = window.innerWidth;
 
         var options = {
 
@@ -83,7 +83,7 @@
             SortOrder: "Descending",
             IncludeItemTypes: "Movie",
             Filters: "IsResumable",
-            Limit: screenWidth >= 1920 ? 6 : (screenWidth >= 1600 ? 4 : 3),
+            Limit: screenWidth >= 1920 ? 5 : (screenWidth >= 1600 ? 4 : 3),
             Recursive: true,
             Fields: "PrimaryImageAspectRatio,MediaSourceCount,SyncInfo",
             CollapseBoxSetItems: false,
@@ -96,9 +96,9 @@
         ApiClient.getItems(userId, options).then(function (result) {
 
             if (result.Items.length) {
-                $('#resumableSection', page).show();
+                page.querySelector('#resumableSection').classList.remove('hide');
             } else {
-                $('#resumableSection', page).hide();
+                page.querySelector('#resumableSection').classList.add('hide');
             }
 
             var view = getResumeView();
@@ -207,13 +207,13 @@
 
     function loadSuggestions(page, userId, parentId) {
 
-        var screenWidth = $(window).width();
+        var screenWidth = window.innerWidth;
 
         var url = ApiClient.getUrl("Movies/Recommendations", {
 
             userId: userId,
             categoryLimit: 6,
-            ItemLimit: screenWidth >= 1920 ? 8 : (screenWidth >= 1600 ? 7 : (screenWidth >= 1200 ? 6 : 5)),
+            ItemLimit: screenWidth >= 1920 ? 8 : (screenWidth >= 1600 ? 8 : (screenWidth >= 1200 ? 6 : 5)),
             Fields: "PrimaryImageAspectRatio,MediaSourceCount,SyncInfo",
             ImageTypeLimit: 1,
             EnableImageTypes: "Primary,Backdrop,Banner,Thumb"
@@ -223,14 +223,14 @@
 
             if (!recommendations.length) {
 
-                $('.noItemsMessage', page).show();
+                page.querySelector('.noItemsMessage').classList.remove('hide');
                 page.querySelector('.recommendations').innerHTML = '';
                 return;
             }
 
             var html = recommendations.map(getRecommendationHtml).join('');
 
-            $('.noItemsMessage', page).hide();
+            page.querySelector('.noItemsMessage').classList.add('hide');
 
             var recs = page.querySelector('.recommendations');
             recs.innerHTML = html;
@@ -241,13 +241,15 @@
     function initSuggestedTab(page, tabContent) {
 
         var containers = tabContent.querySelectorAll('.itemsContainer');
-        if (enableScrollX()) {
-            $(containers).addClass('hiddenScrollX');
-        } else {
-            $(containers).removeClass('hiddenScrollX');
-        }
+        for (var i = 0, length = containers.length; i < length; i++) {
+            if (enableScrollX()) {
+                containers[i].classList.add('hiddenScrollX');
+            } else {
+                containers[i].classList.remove('hiddenScrollX');
+            }
 
-        $(containers).createCardMenus();
+            libraryBrowser.createCardMenus(containers[i]);
+        }
     }
 
     function loadSuggestionsTab(view, params, tabContent) {
@@ -279,22 +281,10 @@
             loadSuggestionsTab(view, params, tabContent);
         };
 
-        $('.recommendations', view).createCardMenus();
+        libraryBrowser.createCardMenus(view.querySelector('.recommendations'));
 
         var mdlTabs = view.querySelector('.libraryViewNav');
 
-        function onPlaybackStop(e, state) {
-
-            if (state.NowPlayingItem && state.NowPlayingItem.MediaType == 'Video') {
-
-                mdlTabs.dispatchEvent(new CustomEvent("tabchange", {
-                    detail: {
-                        selectedTabIndex: libraryBrowser.selectedTab(mdlTabs)
-                    }
-                }));
-            }
-        }
-
         var baseUrl = 'movies.html';
         var topParentId = params.topParentId;
         if (topParentId) {
@@ -306,9 +296,8 @@
         var tabControllers = [];
         var renderedTabs = [];
 
-        function loadTab(page, index) {
+        function getTabController(page, index, callback) {
 
-            var tabContent = view.querySelector('.pageTabContent[data-index=\'' + index + '\']');
             var depends = [];
 
             switch (index) {
@@ -335,12 +324,14 @@
             }
 
             require(depends, function (controllerFactory) {
-
+                var tabContent;
                 if (index == 0) {
+                    tabContent = view.querySelector('.pageTabContent[data-index=\'' + index + '\']');
                     self.tabContent = tabContent;
                 }
                 var controller = tabControllers[index];
                 if (!controller) {
+                    tabContent = view.querySelector('.pageTabContent[data-index=\'' + index + '\']');
                     controller = index ? new controllerFactory(view, params, tabContent) : self;
                     tabControllers[index] = controller;
 
@@ -349,6 +340,24 @@
                     }
                 }
 
+                callback(controller);
+            });
+        }
+
+        function preLoadTab(page, index) {
+
+            getTabController(page, index, function (controller) {
+                if (renderedTabs.indexOf(index) == -1) {
+                    if (controller.preRender) {
+                        controller.preRender();
+                    }
+                }
+            });
+        }
+
+        function loadTab(page, index) {
+
+            getTabController(page, index, function (controller) {
                 if (renderedTabs.indexOf(index) == -1) {
                     renderedTabs.push(index);
                     controller.renderTab();
@@ -356,6 +365,9 @@
             });
         }
 
+        mdlTabs.addEventListener('beforetabchange', function (e) {
+            preLoadTab(view, parseInt(e.detail.selectedTabIndex));
+        });
         mdlTabs.addEventListener('tabchange', function (e) {
             loadTab(view, parseInt(e.detail.selectedTabIndex));
         });
@@ -381,6 +393,19 @@
             }
         });
 
+        function onPlaybackStop(e, state) {
+
+            if (state.NowPlayingItem && state.NowPlayingItem.MediaType == 'Video') {
+
+                renderedTabs = [];
+                mdlTabs.dispatchEvent(new CustomEvent("tabchange", {
+                    detail: {
+                        selectedTabIndex: libraryBrowser.selectedTab(mdlTabs)
+                    }
+                }));
+            }
+        }
+
         view.addEventListener('viewshow', function (e) {
             Events.on(MediaController, 'playbackstop', onPlaybackStop);
         });
